#[non_exhaustive]pub enum PivotingStrategy {
Diagonal,
Partial,
PartialDiag,
Rook,
RookDiag,
Full,
}Expand description
pivoting strategy for choosing the pivots
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Diagonal
👎Deprecated
deprecated, corresponds to partial pivoting
Partial
searches for the k-th pivot in the k-th column
PartialDiag
searches for the k-th pivot in the k-th column, as well as the tail of the diagonal of the matrix
Rook
searches for pivots that are locally optimal
RookDiag
searches for pivots that are locally optimal, as well as the tail of the diagonal of the matrix
Full
searches for pivots that are globally optimal